summaryrefslogtreecommitdiffstats
path: root/kexi/kexiutils/styleproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexiutils/styleproxy.h')
-rw-r--r--kexi/kexiutils/styleproxy.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/kexiutils/styleproxy.h b/kexi/kexiutils/styleproxy.h
index 779298ee9..867ef23d5 100644
--- a/kexi/kexiutils/styleproxy.h
+++ b/kexi/kexiutils/styleproxy.h
@@ -48,13 +48,13 @@ namespace KexiUtils {
class KEXIUTILS_EXPORT StyleProxy : public TQStyle
{
public:
/*! Creates a new style proxy object. \a tqparentStyle pointer will not be kept
(because it's most likely owned by the application: a new TQStyle instance
for this name will be created internally. */
- StyleProxy(TQStyle* tqparentStyle);
+ StyleProxy(TQStyle* parentStyle);
virtual ~StyleProxy();
- TQStyle* tqparentStyle() const;
+ TQStyle* parentStyle() const;
void setParentStyle(TQStyle* style);
virtual void polish( TQWidget *w ) { m_style->polish(w); }
@@ -48,13 +48,13 @@ namespace KexiUtils {
{
public:
- /*! Creates a new style proxy object. \a tqparentStyle pointer will not be kept
+ /*! Creates a new style proxy object. \a parentStyle pointer will not be kept
(because it's most likely owned by the application: a new TQStyle instance
for this name will be created internally. */